"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var base_proxy_1 = require("../base-proxy");
var version = require("../../../package.json").version;
var StateTrackerProxy = /** @class */ (function (_super) {
    __extends(StateTrackerProxy, _super);
    function StateTrackerProxy(cfg, request, logger) {
        var _this = _super.call(this, cfg, request, logger) || this;
        if (!cfg) {
            throw new Error("cfg is required");
        }
        if (!request) {
            throw new Error("request is required");
        }
        if (!logger) {
            throw new Error("logger is required");
        }
        return _this;
    }
    StateTrackerProxy.prototype.checkMappingStatus = function (callback) {
        var _this = this;
        var routeVersion = this.cfg.token.hasValue ? "/v3" : "/v2";
        var url = routeVersion + '/testExecution';
        var queryParams = {
            customerId: this.cfg.customerId.value,
            environment: this.cfg.labId.hasValue && this.cfg.labId.value || this.cfg.environmentName.value
        };
        url += "?customerId=" + queryParams.customerId + "&environment=" + queryParams.environment;
        this.logger.info("[TO TST] - checkMappingStatus. Url '" + url + "'.");
        this.get(url, function (err, data) {
            _this.logger.info("[FROM TST] - checkMappingStatus. Had Error: " + (err != null));
            if (err) {
                _this.logger.error("[ACTIVE EXECUTION] Error checking for active execution: " + err);
                return callback(err, false);
            }
            // No mapping found -> no active execution
            if (!err && data == null) {
                _this.logger.info("[ACTIVE EXECUTION] couldn't find active execution. not sending footprints.");
                return callback(null, false);
            }
            // execution is pending delete -> no active execution
            if (data.status == "pendingDelete") {
                _this.logger.info("[ACTIVE EXECUTION] execution is pending delete. sending last footprints");
                return callback(null, true);
            }
            // active execution
            if (data.status == null || data.status != "created") {
                _this.logger.warn("[ACTIVE EXECUTION] unexpected status. status: " + data.status);
            }
            _this.logger.info("[ACTIVE EXECUTION] active execution for: " + JSON.stringify(queryParams) + ". data: " + JSON.stringify(data));
            return callback(null, true);
        });
    };
    ;
    StateTrackerProxy.prototype.checkTestStatus = function (executionId, testName, callback) {
        var _this = this;
        var relativeUrl = "/" + ["v2", "test", "status", executionId].map(encodeURIComponent).join("/") + "?testName=" + encodeURIComponent(testName);
        this.logger.info("Checking test end at '" + relativeUrl + "'.");
        this.get(relativeUrl, function (err, response) {
            if (err) {
                _this.logger.warn("checkTestStatus - Failed check test status.URL: '" + relativeUrl + "'. Error:" + err.message + ", Stack:\n" + err.stack);
                return callback(err, null);
            }
            var isStillRunning = true;
            if (response && response.data && response.data.tests) {
                var tests = response.data.tests;
                if (tests.length != 1) {
                    _this.logger.warn("checkTestStatus - Server returned several tests for URL: '" + relativeUrl + "'. That's probably means that those are data driven tests. Response:", response);
                }
                for (var i = 0; i < tests.length; i++) {
                    isStillRunning = tests[i].status != "ended";
                    if (isStillRunning) {
                        break;
                    }
                }
            }
            else {
                _this.logger.warn("checkTestStatus - Server didn't return a response or 'response.data' or 'response.data.tests' fields were null. Response:", response);
            }
            _this.logger.info("checkTestStatus - isStillRunning: " + isStillRunning);
            return callback(err, isStillRunning);
        });
    };
    return StateTrackerProxy;
}(base_proxy_1.BaseProxy));
exports.StateTrackerProxy = StateTrackerProxy;
//# sourceMappingURL=state-tracker-proxy.js.map